@@ -230,7 +230,7 @@ mympz_is_prime (mpz_srcptr n, int miller_rabin_reps)
 	}
 
 	/* if n < 25*10^9, we are now sure this
-	   is a prime since the only n less then that
+	   is a prime since the only n less than that
 	   that is a composite and strong pseudoprime to 2,3,5,7
 	   is n = 3215031751
         ref:
@@ -379,11 +379,11 @@ factor_using_pollard_rho (GArray *fact, mpz_t n, int a_int)
     {
 S2:
       if (evalnode_hook != NULL) {
-	    static int i = 0;
-	    if (i++ > run_hook_every) {
-		    i = 0;
-		    (*evalnode_hook) ();
-	    }
+	      static int i = 0;
+	      if G_UNLIKELY ((i++ & RUN_HOOK_EVERY_MASK) == RUN_HOOK_EVERY_MASK) {
+		      (*evalnode_hook)();
+		      i = 0;
+	      }
       }
       if (interrupted) {
 	      mpz_set_ui (n, 1);
